@@ -26,12 +26,15 @@ int camera_get_config (Camera *camera, CameraWidget **window, GPContext *context
 int camera_set_config (Camera *camera, CameraWidget *window, GPContext *context);
 int camera_prepare_capture (Camera *camera, GPContext *context);
 int camera_unprepare_capture (Camera *camera, GPContext *context);
+int camera_canon_eos_update_capture_target(Camera *camera, GPContext *context, int value);
 
 /* library.c */
 void report_result (GPContext *context, short result, short vendor);
 int translate_ptp_result (short result);
 void fixup_cached_deviceinfo (Camera *camera, PTPDeviceInfo*);
 
+int init_ptp_fs (Camera *camera, GPContext *context);
+
 struct _CameraPrivateLibrary {
 	PTPParams params;
 	unsigned long bugs;
