@@ -52,7 +52,6 @@
 #  define N_(String) (String)
 #endif
 
-typedef enum _SierraPacket SierraPacket;
 enum _SierraPacket {
 	NUL				= 0x00,
 	SIERRA_PACKET_DATA		= 0x02,
@@ -66,6 +65,7 @@ enum _SierraPacket {
 	SIERRA_PACKET_SESSION_ERROR	= 0xfc,
 	SIERRA_PACKET_SESSION_END	= 0xff
 };
+typedef enum _SierraPacket SierraPacket;
 
 /* Size of requested packet */
 #define SIERRA_PACKET_SIZE		32774
@@ -98,7 +98,7 @@ int sierra_change_folder (Camera *camera, const char *folder, GPContext *context
 
 	/* We will later need a path ending with '/'. */
 	memset (target, 0, sizeof (target));
-	if (folder && folder[0])
+	if (folder[0])
 		strncpy (target, folder, sizeof (target) - 1);
 	if (target[strlen (target) - 1] != '/')
 		strcat (target, "/");
@@ -298,6 +298,7 @@ int sierra_check_battery_capacity (Camera *camera, GPContext *context)
 				     _("Cannot retrieve the battery capacity"));
 		return ret;
 	}
+	if (!capacity) return GP_OK; /* might just be an error */
 
 	if (capacity < 5) {
 		gp_context_error (context,
@@ -765,7 +766,7 @@ sierra_transmit_ack (Camera *camera, char *packet, GPContext *context)
 			GP_DEBUG ("Transmission successful.");
 			return GP_OK;
 		case SIERRA_PACKET_INVALID:
-			gp_context_error (context, _("Packet got rejected "
+			gp_context_error (context, _("Packet was rejected "
 				"by camera. Please contact "
 				"%s."), MAIL_GPHOTO_DEVEL);
 			return GP_ERROR;
