@@ -187,7 +187,8 @@ gp_abilities_list_load_dir (CameraAbilitiesList *list, const char *dir,
 	}
 	if (1) { /* a new block in which we can define a temporary variable */
 		int ret;
-		foreach_data_t foreach_data = { flist, GP_OK };
+		foreach_data_t foreach_data = { NULL, GP_OK };
+		foreach_data.list = flist;
 		lt_dlinit ();
 		lt_dladdsearchdir (dir);
 		ret = lt_dlforeachfile (dir, foreach_func, &foreach_data);
